@@ -19,7 +19,7 @@ def get_template_path(template_name):
     script_path = os.path.abspath(__file__)
     module_path = os.path.dirname(script_path)
     project_path = os.path.dirname(module_path)
-    cookiecutters_path = os.path.join(project_path, "templates")
+    cookiecutters_path = os.path.join(project_path, "cookiecutters")
     return os.path.join(cookiecutters_path, template_name)
     
 
@@ -36,9 +36,10 @@ def activate_venv():
     activate_file = os.path.join(parent, "env", env_activate_script, "activate")
     os.system(f"{activate_file} && pip install -r requirements.txt")
 
+
 @app.command()
 def main(template_name):
-    cookiecutter("https://github.com/MohammedBajuaifer/drf-starter-templates.git")
+    cookiecutter(template_name)
 
     activate_venv()
 
